==> rt-2.3.1.jar: module-info.java <==
module com.sun.xml.ws {
    /* transitive */ requires java.xml.ws;
    requires com.sun.xml.bind;
    requires com.sun.xml.messaging.saaj;
    requires com.sun.xml.ws.policy;
    requires com.sun.istack.runtime;
    requires com.sun.xml.txw2;
    requires org.jvnet.staxex;
    requires org.jvnet.mimepull;
    requires com.sun.xml.streambuffer;
    requires javax.jws;
    requires java.annotation;
    requires java.desktop;
    requires java.logging;
    requires java.management;
    requires jdk.httpserver;
    /* transitive */ requires java.activation;
    /* transitive */ requires java.xml;
    /* transitive */ requires java.xml.bind;

    exports com.oracle.webservices.api;
    exports com.oracle.webservices.api.databinding;
    exports com.oracle.webservices.api.message;
    exports com.sun.xml.ws.api;
    exports com.sun.xml.ws.api.addressing;
    exports com.sun.xml.ws.api.databinding;
    exports com.sun.xml.ws.api.ha;
    exports com.sun.xml.ws.api.message;
    exports com.sun.xml.ws.api.model;
    exports com.sun.xml.ws.api.model.wsdl;
    exports com.sun.xml.ws.api.server;
    exports com.sun.xml.ws.api.streaming;
    exports com.sun.xml.ws.api.wsdl.parser;
    exports com.sun.xml.ws.api.wsdl.writer;
    exports com.sun.xml.ws.api.pipe;
    exports com.sun.xml.ws.developer;
    exports com.sun.xml.ws.resources;
    exports com.sun.xml.ws.message.stream;
    exports com.sun.xml.ws.addressing;
    exports com.sun.xml.ws.addressing.v200408;
    exports com.sun.xml.ws.binding;
    exports com.sun.xml.ws.db;
    exports com.sun.xml.ws.model;
    exports com.sun.xml.ws.server;
    exports com.sun.xml.ws.spi.db;
    exports com.sun.xml.ws.streaming;
    exports com.sun.xml.ws.transport;
    exports com.sun.xml.ws.transport.http;
    exports com.sun.xml.ws.util;
    exports com.sun.xml.ws.util.exception;
    exports com.sun.xml.ws.util.xml;
    exports com.sun.xml.ws.wsdl.parser;
    exports com.sun.xml.ws.wsdl.writer;
    exports com.sun.xml.ws.encoding;

    opens com.sun.xml.ws.runtime.config to java.xml.bind;
    opens com.sun.xml.ws.fault to java.xml.bind;
    opens com.sun.xml.ws.addressing to java.xml.bind;
    opens com.sun.xml.ws.addressing.v200408 to java.xml.bind;
    opens com.sun.xml.ws.developer to java.xml.bind;
    opens com.oracle.xmlns.webservices.jaxws_databinding to java.xml.bind;

}

==> rt-2.3.2-1.jar: module-info.java <==
module com.sun.xml.ws {
    requires java.desktop;
    requires java.logging;
    requires java.management;
    requires jdk.httpserver;
    /* transitive */ requires jakarta.activation;
    requires java.annotation;
    requires java.jws;
    /* transitive */ requires java.xml;
    /* transitive */ requires java.xml.bind;
    requires java.xml.soap;
    /* transitive */ requires java.xml.ws;
    requires org.jvnet.mimepull;
    requires org.jvnet.staxex;
    requires com.sun.istack.runtime;
    requires com.sun.xml.bind;
    requires com.sun.xml.streambuffer;
    requires com.sun.xml.txw2;
    requires com.sun.xml.ws.policy;

    exports com.oracle.webservices.api;
    exports com.oracle.webservices.api.databinding;
    exports com.oracle.webservices.api.message;
    exports com.sun.xml.ws.api;
    exports com.sun.xml.ws.api.addressing;
    exports com.sun.xml.ws.api.databinding;
    exports com.sun.xml.ws.api.ha;
    exports com.sun.xml.ws.api.message;
    exports com.sun.xml.ws.api.model;
    exports com.sun.xml.ws.api.model.wsdl;
    exports com.sun.xml.ws.api.server;
    exports com.sun.xml.ws.api.streaming;
    exports com.sun.xml.ws.api.wsdl.parser;
    exports com.sun.xml.ws.api.wsdl.writer;
    exports com.sun.xml.ws.api.pipe;
    exports com.sun.xml.ws.developer;
    exports com.sun.xml.ws.resources;
    exports com.sun.xml.ws.message.stream;
    exports com.sun.xml.ws.addressing;
    exports com.sun.xml.ws.addressing.v200408;
    exports com.sun.xml.ws.binding;
    exports com.sun.xml.ws.db;
    exports com.sun.xml.ws.model;
    exports com.sun.xml.ws.server;
    exports com.sun.xml.ws.spi.db;
    exports com.sun.xml.ws.streaming;
    exports com.sun.xml.ws.transport;
    exports com.sun.xml.ws.transport.http;
    exports com.sun.xml.ws.util;
    exports com.sun.xml.ws.util.exception;
    exports com.sun.xml.ws.util.xml;
    exports com.sun.xml.ws.wsdl.parser;
    exports com.sun.xml.ws.wsdl.writer;
    exports com.sun.xml.ws.encoding;
    exports com.sun.xml.ws.spi to java.xml.ws;

    opens com.sun.xml.ws.runtime.config to java.xml.bind;
    opens com.sun.xml.ws.fault to java.xml.bind;
    opens com.sun.xml.ws.addressing to java.xml.bind;
    opens com.sun.xml.ws.addressing.v200408 to java.xml.bind;
    opens com.sun.xml.ws.developer to java.xml.bind;
    opens com.oracle.xmlns.webservices.jaxws_databinding to java.xml.bind;

    provides Provider with ProviderImpl;

}
